==> DAAG_0.32.tar.gz: DAAG/data/leafshape17.R <==
"leafshape17" <-
structure(list(bladelen = c(6.93, 7.27, 7.43, 8, 8.08, 8.48, 
8.56, 8.72, 9.153333, 9.353333, 9.48, 9.56, 10.06, 10.06, 10.11, 
10.37, 10.44, 10.5, 10.55, 10.87, 11.22, 11.66, 11.86, 12.23, 
12.84, 12.9, 12.96, 13.03, 13.4, 13.413333, 13.59, 14.36, 14.4, 
14.6, 14.9, 16.49, 16.67, 17.04, 19.89, 24.43, 30.35, 13.98, 
14.45, 15.25, 15.3, 15.348, 15.46, 15.56, 17, 17.8, 17.97, 18.76, 
19.68, 20.98, 22.215, 22.64, 25.275, 26.55, 26.9925, 35.843333, 
42.275), petiole = c(0.449064, 0.26172, 0.766033, 0.5928, 0.4929, 
0.819168, 0.598344, 0.5901, 0.520824648, 0.893243302, 0.239844, 
0.65964, 1.259512, 0.602594, 0.7446015, 0.281, 0.489636, 0.09975, 
1.00014, 0.84786, 1.104048, 0.871, 0.856292, 0.386468, 0.889812, 
0.2709, 0.415368, 0.28763725, 1.47802, 0.854871952, 0.9696465, 
0.548552, 0.45072, 1.04828, 0.93125, 1.205419, 0.698473, 1.159572, 
1.1795, 1.2044, 1.6586275, 1.50984, 2.88422, 0.840275, 1.87425, 
1.8049248, 1.842832, 1.039408, 0.4148, 1.55572, 3.5212215, 1.876, 
6.5928, 3.268684, 10.4743725, 0.875036, 3.634545, 2.6350875, 
3.83563425, 3.799393298, 1.49442125), bladewid = c(3.1, 2.5, 
2.98, 3.06, 3.03, 4.33, 4.82, 4.88, 3.01, 4.04, 3.24, 2.84, 3.37, 
3.79, 3.72, 3.48, 3.99, 3.33, 5.16, 4.01, 4.65, 3.62, 4.33, 4.11, 
4.36, 4.18, 4.03, 3.29, 5.59, 4.34, 5.64, 4.26, 3.975, 3.05, 
4.57, 7.61, 5.68, 6.86, 7.81, 6.96, 6.78, 3.9, 5.72, 3, 5.88, 
4.84, 5.85, 4.72, 7.22, 5.28, 6.15, 7.19, 8.16, 6.58, 11.46, 
3.8, 6.85, 5.92, 8.53, 9.51, 23.45), lattitude = c(17.1, 17.1, 
17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 
17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 
17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 
17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 
17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 
17.1, 17.1, 17.1, 17.1), logwid = c(1.1314021114911, 0.916290731874155, 
1.09192330051731, 1.11841491596429, 1.10856261952128, 1.4655675420144, 
1.57277392806251, 1.58514521986506, 1.10194007876078, 1.39624469197306, 
1.17557332980424, 1.04380405217311, 1.21491274436427, 1.33236601909433, 
1.31372366828506, 1.24703229378638, 1.38379123090177, 1.20297230399235, 
1.64093657949347, 1.38879124131848, 1.53686721959927, 1.28647402583768, 
1.4655675420144, 1.41342302850814, 1.47247205736094, 1.43031124653667, 
1.39376637595859, 1.19088756477728, 1.72097928716701, 1.46787434811231, 
1.72988406550997, 1.44926916028128, 1.3800247481063, 1.11514159061932, 
1.51951320490611, 2.0294631718736, 1.73695123273306, 1.92570744173779, 
2.0554049638516, 1.94017947434633, 1.9139771019523, 1.3609765531356, 
1.74396880539171, 1.09861228866811, 1.77155676191054, 1.57691472072854, 
1.76644166124377, 1.55180879959746, 1.97685495290474, 1.66392609771817, 
1.81645208181843, 1.97269117173296, 2.09924416897602, 1.88403474533723, 
2.43886271128659, 1.33500106673234, 1.92424865227413, 1.77833644889591, 
2.14358936150359, 2.2523438765573, 3.15487049489229), logpet = c(-0.800589862422096, 
-1.3404800489806, -0.266530029229555, -0.52289820500026, -0.707448965270805, 
-0.199466087959853, -0.513589439588722, -0.527463264919014, -0.652341862018734, 
-0.112896280567409, -1.42776656698173, -0.416061047321568, 0.230724344355454, 
-0.50651160918914, -0.294906103041118, -1.26940060964839, -0.714093021075411, 
-2.30508822321216, 0.0001399902009146, -0.165039751159427, 0.098983425170621, 
-0.138113302129634, -0.155143839513777, -0.95070620869019, -0.116745074524464, 
-1.30600552989109, -0.87859040469133, -1.24605514135536, 0.390703354234185, 
-0.156803585003776, -0.0308237068962393, -0.600473199749529, 
-0.796908974854075, 0.0471507257863323, -0.0712275092883678, 
0.186827224345103, -0.358858755291342, 0.148050971516508, 0.165090619865593, 
0.185981517625442, 0.505990453145918, 0.412003684947747, 1.05925449945367, 
-0.174026059769848, 0.628208579401034, 0.590518928867095, 0.611303518808388, 
0.0386513203107086, -0.879958802626765, 0.441938460977392, 1.25880794645897, 
0.629141850584033, 1.88597814446704, 1.18438745742266, 2.34893155947925, 
-0.133490250613724, 1.29048393121134, 0.96891638827311, 1.34433480576008, 
1.33484139556453, 0.401739008145089), loglen = c(1.93585981320181, 
1.98375629154543, 2.00552585872967, 2.07944154167984, 2.089391872533, 
2.13771044980381, 2.14710019015365, 2.16561923792089, 2.21411807525511, 
2.23573275036829, 2.24918431626693, 2.25758772706331, 2.30856716467159, 
2.30856716467159, 2.31352503303238, 2.33891702224144, 2.34564458245449, 
2.35137525716348, 2.35612585992208, 2.38600670113312, 2.41769790009455, 
2.45616418092235, 2.47317139356958, 2.50389194969908, 2.55256529826182, 
2.55722731136763, 2.56186769092413, 2.56725439113675, 2.59525470695687, 
2.59624921227248, 2.60933422816305, 2.66444656362008, 2.66722820658195, 
2.68102152871429, 2.70136121295141, 2.80275413657151, 2.8136106967627, 
2.83556352140117, 2.99021709286588, 3.19581188526965, 3.41279651750551, 
2.63762773680566, 2.67069441455844, 2.72457950305342, 2.72785282839839, 
2.73098517238471, 2.73825604315928, 2.74470351875025, 2.83321334405622, 
2.87919845729804, 2.88870370079547, 2.93172694357808, 2.97960289162411, 
3.04356960296815, 3.10076773638787, 3.11971825333498, 3.22981576490653, 
3.27902974768795, 3.29555904963916, 3.5791575804346, 3.74419589478464
), arch = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1)), .Names = c("bladelen", "petiole", "bladewid", "lattitude", 
"logwid", "logpet", "loglen", "arch"), row.names = c("186", "187", 
"188", "189", "190", "191", "192", "193", "194", "195", "196", 
"197", "198", "199", "200", "201", "202", "203", "204", "205", 
"206", "207", "208", "209", "210", "211", "212", "213", "214", 
"215", "216", "217", "218", "219", "220", "221", "222", "223", 
"224", "225", "226", "227", "228", "229", "230", "231", "232", 
"233", "234", "235", "236", "237", "238", "239", "240", "241", 
"242", "243", "244", "245", "246"), class = "data.frame")

==> DAAG_0.84.tar.gz: DAAG/data/leafshape17.R <==
"leafshape17" <-
structure(list(bladelen = c(6.93, 7.27, 7.43, 8, 8.08, 8.48, 
8.56, 8.72, 9.153333, 9.353333, 9.48, 9.56, 10.06, 10.06, 10.11, 
10.37, 10.44, 10.5, 10.55, 10.87, 11.22, 11.66, 11.86, 12.23, 
12.84, 12.9, 12.96, 13.03, 13.4, 13.413333, 13.59, 14.36, 14.4, 
14.6, 14.9, 16.49, 16.67, 17.04, 19.89, 24.43, 30.35, 13.98, 
14.45, 15.25, 15.3, 15.348, 15.46, 15.56, 17, 17.8, 17.97, 18.76, 
19.68, 20.98, 22.215, 22.64, 25.275, 26.55, 26.9925, 35.843333, 
42.275), petiole = c(0.449064, 0.26172, 0.766033, 0.5928, 0.4929, 
0.819168, 0.598344, 0.5901, 0.520824648, 0.893243302, 0.239844, 
0.65964, 1.259512, 0.602594, 0.7446015, 0.281, 0.489636, 0.09975, 
1.00014, 0.84786, 1.104048, 0.871, 0.856292, 0.386468, 0.889812, 
0.2709, 0.415368, 0.28763725, 1.47802, 0.854871952, 0.9696465, 
0.548552, 0.45072, 1.04828, 0.93125, 1.205419, 0.698473, 1.159572, 
1.1795, 1.2044, 1.6586275, 1.50984, 2.88422, 0.840275, 1.87425, 
1.8049248, 1.842832, 1.039408, 0.4148, 1.55572, 3.5212215, 1.876, 
6.5928, 3.268684, 10.4743725, 0.875036, 3.634545, 2.6350875, 
3.83563425, 3.799393298, 1.49442125), bladewid = c(3.1, 2.5, 
2.98, 3.06, 3.03, 4.33, 4.82, 4.88, 3.01, 4.04, 3.24, 2.84, 3.37, 
3.79, 3.72, 3.48, 3.99, 3.33, 5.16, 4.01, 4.65, 3.62, 4.33, 4.11, 
4.36, 4.18, 4.03, 3.29, 5.59, 4.34, 5.64, 4.26, 3.975, 3.05, 
4.57, 7.61, 5.68, 6.86, 7.81, 6.96, 6.78, 3.9, 5.72, 3, 5.88, 
4.84, 5.85, 4.72, 7.22, 5.28, 6.15, 7.19, 8.16, 6.58, 11.46, 
3.8, 6.85, 5.92, 8.53, 9.51, 23.45), latitude = c(17.1, 17.1, 
17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 
17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 
17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 
17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 
17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 17.1, 
17.1, 17.1, 17.1, 17.1), logwid = c(1.1314021114911, 0.916290731874155, 
1.09192330051731, 1.11841491596429, 1.10856261952128, 1.4655675420144, 
1.57277392806251, 1.58514521986506, 1.10194007876078, 1.39624469197306, 
1.17557332980424, 1.04380405217311, 1.21491274436427, 1.33236601909433, 
1.31372366828506, 1.24703229378638, 1.38379123090177, 1.20297230399235, 
1.64093657949347, 1.38879124131848, 1.53686721959927, 1.28647402583768, 
1.4655675420144, 1.41342302850814, 1.47247205736094, 1.43031124653667, 
1.39376637595859, 1.19088756477728, 1.72097928716701, 1.46787434811231, 
1.72988406550997, 1.44926916028128, 1.3800247481063, 1.11514159061932, 
1.51951320490611, 2.0294631718736, 1.73695123273306, 1.92570744173779, 
2.0554049638516, 1.94017947434633, 1.9139771019523, 1.3609765531356, 
1.74396880539171, 1.09861228866811, 1.77155676191054, 1.57691472072854, 
1.76644166124377, 1.55180879959746, 1.97685495290474, 1.66392609771817, 
1.81645208181843, 1.97269117173296, 2.09924416897602, 1.88403474533723, 
2.43886271128659, 1.33500106673234, 1.92424865227413, 1.77833644889591, 
2.14358936150359, 2.2523438765573, 3.15487049489229), logpet = c(-0.800589862422096, 
-1.3404800489806, -0.266530029229555, -0.52289820500026, -0.707448965270805, 
-0.199466087959853, -0.513589439588722, -0.527463264919014, -0.652341862018734, 
-0.112896280567409, -1.42776656698173, -0.416061047321568, 0.230724344355454, 
-0.50651160918914, -0.294906103041118, -1.26940060964839, -0.714093021075411, 
-2.30508822321216, 0.0001399902009146, -0.165039751159427, 0.098983425170621, 
-0.138113302129634, -0.155143839513777, -0.95070620869019, -0.116745074524464, 
-1.30600552989109, -0.87859040469133, -1.24605514135536, 0.390703354234185, 
-0.156803585003776, -0.0308237068962393, -0.600473199749529, 
-0.796908974854075, 0.0471507257863323, -0.0712275092883678, 
0.186827224345103, -0.358858755291342, 0.148050971516508, 0.165090619865593, 
0.185981517625442, 0.505990453145918, 0.412003684947747, 1.05925449945367, 
-0.174026059769848, 0.628208579401034, 0.590518928867095, 0.611303518808388, 
0.0386513203107086, -0.879958802626765, 0.441938460977392, 1.25880794645897, 
0.629141850584033, 1.88597814446704, 1.18438745742266, 2.34893155947925, 
-0.133490250613724, 1.29048393121134, 0.96891638827311, 1.34433480576008, 
1.33484139556453, 0.401739008145089), loglen = c(1.93585981320181, 
1.98375629154543, 2.00552585872967, 2.07944154167984, 2.089391872533, 
2.13771044980381, 2.14710019015365, 2.16561923792089, 2.21411807525511, 
2.23573275036829, 2.24918431626693, 2.25758772706331, 2.30856716467159, 
2.30856716467159, 2.31352503303238, 2.33891702224144, 2.34564458245449, 
2.35137525716348, 2.35612585992208, 2.38600670113312, 2.41769790009455, 
2.45616418092235, 2.47317139356958, 2.50389194969908, 2.55256529826182, 
2.55722731136763, 2.56186769092413, 2.56725439113675, 2.59525470695687, 
2.59624921227248, 2.60933422816305, 2.66444656362008, 2.66722820658195, 
2.68102152871429, 2.70136121295141, 2.80275413657151, 2.8136106967627, 
2.83556352140117, 2.99021709286588, 3.19581188526965, 3.41279651750551, 
2.63762773680566, 2.67069441455844, 2.72457950305342, 2.72785282839839, 
2.73098517238471, 2.73825604315928, 2.74470351875025, 2.83321334405622, 
2.87919845729804, 2.88870370079547, 2.93172694357808, 2.97960289162411, 
3.04356960296815, 3.10076773638787, 3.11971825333498, 3.22981576490653, 
3.27902974768795, 3.29555904963916, 3.5791575804346, 3.74419589478464
), arch = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1)), .Names = c("bladelen", "petiole", "bladewid", "latitude", 
"logwid", "logpet", "loglen", "arch"), row.names = c("186", "187", 
"188", "189", "190", "191", "192", "193", "194", "195", "196", 
"197", "198", "199", "200", "201", "202", "203", "204", "205", 
"206", "207", "208", "209", "210", "211", "212", "213", "214", 
"215", "216", "217", "218", "219", "220", "221", "222", "223", 
"224", "225", "226", "227", "228", "229", "230", "231", "232", 
"233", "234", "235", "236", "237", "238", "239", "240", "241", 
"242", "243", "244", "245", "246"), class = "data.frame")
